@@ -116,7 +116,7 @@ const char* hts_optalias[][4] = {
   {"structure","-N","param",""}, {"user-structure","-N","param1",""},
   {"long-names","-L","param",""},
   {"keep-links","-K","param",""},
-  {"mime-html","-%M","param",""}, {"mht","-%M","param",""},
+  {"mime-html","-%M","single",""}, {"mht","-%M","single",""},
   {"replace-external","-x","single",""},
   {"disable-passwords","-%x","single",""},{"disable-password","-%x","single",""},
   {"include-query-string","-%q","single",""},
