@@ -75,6 +75,13 @@ extern "C" {
 #define min(a,b) ((a)>(b)?(b):(a))
 #define max(a,b) ((a)>(b)?(a):(b))
 
+#ifndef _WIN32
+#undef Sleep
+#define min(a,b) ((a)>(b)?(b):(a))
+#define max(a,b) ((a)>(b)?(a):(b))
+#define Sleep(a) { if (((a)*1000)%1000000) usleep(((a)*1000)%1000000); if (((a)*1000)/1000000) sleep(((a)*1000)/1000000); }
+#endif
+
 // teste galit de 2 chars, case insensitive
 #define hichar(a) ((((a)>='a') && ((a)<='z')) ? ((a)-('a'-'A')) : (a))
 #define streql(a,b) (hichar(a)==hichar(b))
@@ -98,25 +105,8 @@ extern "C" {
 typedef void (*t_abortLog)(char* msg, char* file, int line);
 extern HTSEXT_API t_abortLog abortLog__;
 #define abortLog(a) abortLog__(a, __FILE__, __LINE__)
-#define abortLogFmt(a) do { \
-  FILE* fp = fopen("CRASH.TXT", "wb"); \
-  if (!fp) fp = fopen("/tmp/CRASH.TXT", "wb"); \
-  if (!fp) fp = fopen("C:\\CRASH.TXT", "wb"); \
-  if (!fp) fp = fopen("\\Temp\\CRASH.TXT", "wb"); \
-  if (!fp) fp = fopen("\\CRASH.TXT", "wb"); \
-  if (!fp) fp = fopen("CRASH.TXT", "wb"); \
-  if (fp) { \
-    fprintf(fp, "HTTrack " HTTRACK_VERSIONID " closed at '" __FILE__ "', line %d\r\n", __LINE__); \
-    fprintf(fp, "Reason:\r\n"); \
-    fprintf(fp, a); \
-    fprintf(fp, "\r\n"); \
-    fflush(fp); \
-    fclose(fp); \
-  } \
-} while(0)
-
-
 #define _ ,
+#ifndef _WIN32_WCE
 #define abortLogFmt(a) do { \
   FILE* fp = fopen("CRASH.TXT", "wb"); \
   if (!fp) fp = fopen("/tmp/CRASH.TXT", "wb"); \
@@ -133,6 +123,12 @@ extern HTSEXT_API t_abortLog abortLog__;
     fclose(fp); \
   } \
 } while(0)
+#else
+#define abortLogFmt(a) do { \
+  XCEShowMessageA("HTTrack " HTTRACK_VERSIONID " closed at '" __FILE__ "', line %d\r\nReason:\r\n%s\r\n", __LINE__, a); \
+} while(0)
+#endif
+
 #define assertf(exp) do { \
   if (! ( exp ) ) { \
     abortLog("assert failed: " #exp); \
