@@ -153,7 +153,7 @@ void cache_mayadd(httrackp* opt,cache_back* cache,htsblk* r,char* url_adr,char*
             if (url_save == NULL && r->statuscode / 100 >= 3) {
               // cached "fast" header doesn't uet exists
               if (inthash_read((inthash)cache->cached_tests, concat(url_adr, url_fil), NULL) == 0) {
-                char tempo[HTS_URLMAXSIZE*2];
+                char BIGSTK tempo[HTS_URLMAXSIZE*2];
                 sprintf(tempo, "%d", (int)r->statuscode);
                 if (r->location != NULL && r->location[0] != '\0') {
                   strcatbuff(tempo, "\n");
@@ -220,9 +220,9 @@ struct cache_back_zip_entry {
 
 /* Ajout d'un fichier en cache */
 void cache_add(cache_back* cache,htsblk r,char* url_adr,char* url_fil,char* url_save,int all_in_cache) {
-  char filemame[HTS_URLMAXSIZE*4];
+  char BIGSTK filemame[HTS_URLMAXSIZE*4];
   int dataincache=0;    // put data in cache ?
-  char headers[8192];
+  char BIGSTK headers[8192];
   int headersSize = 0;
   int entryBodySize = 0;
   int entryFilenameSize = 0;
@@ -385,7 +385,7 @@ void cache_add(cache_back* cache,htsblk r,char* url_adr,char* url_fil,char* url_
 void cache_add(cache_back* cache,htsblk r,char* url_adr,char* url_fil,char* url_save,int all_in_cache) {
   int pos;
   char s[256];
-  char buff[HTS_URLMAXSIZE*4];
+  char BIGSTK buff[HTS_URLMAXSIZE*4];
   int ok=1;
   int dataincache=0;    // donne en cache?
   FILE* cache_ndx = cache->ndx;
@@ -548,9 +548,9 @@ htsblk cache_readex(httrackp* opt,cache_back* cache,char* adr,char* fil,char* sa
 // si save==null alors test unqiquement
 static htsblk cache_readex_new(httrackp* opt,cache_back* cache,char* adr,char* fil,char* save,char* location,
                                char* return_save, int readonly) {
-  char location_default[HTS_URLMAXSIZE*2];
-  char buff[HTS_URLMAXSIZE*2];
-  char previous_save[HTS_URLMAXSIZE*2];
+  char BIGSTK location_default[HTS_URLMAXSIZE*2];
+  char BIGSTK buff[HTS_URLMAXSIZE*2];
+  char BIGSTK previous_save[HTS_URLMAXSIZE*2];
   long int hash_pos;
   int hash_pos_return;
   htsblk r;
@@ -584,7 +584,7 @@ static htsblk cache_readex_new(httrackp* opt,cache_back* cache,char* adr,char* f
     if (unzSetOffset((unzFile) cache->zipInput, posInZip) == Z_OK) {
       /* Read header (Max 8KiB) */
       if (unzOpenCurrentFile((unzFile) cache->zipInput) == Z_OK) {
-        char headerBuff[8192 + 2];
+        char BIGSTK headerBuff[8192 + 2];
         int readSizeHeader;
         int totalHeader = 0;
         int dataincache = 0;
@@ -600,7 +600,7 @@ static htsblk cache_readex_new(httrackp* opt,cache_back* cache,char* adr,char* f
           NULL, 0, NULL, 0, headerBuff, sizeof(headerBuff) - 2) == Z_OK ) */
         {
           int offset = 0;
-          char line[HTS_URLMAXSIZE + 2];
+          char BIGSTK line[HTS_URLMAXSIZE + 2];
           int lineEof = 0;
           /*readSizeHeader = (int) strlen(headerBuff);*/
           headerBuff[readSizeHeader] = '\0';
@@ -792,9 +792,9 @@ static htsblk cache_readex_old(httrackp* opt,cache_back* cache,char* adr,char* f
 #else
   char* a;
 #endif
-  char buff[HTS_URLMAXSIZE*2];
-  char location_default[HTS_URLMAXSIZE*2];
-  char previous_save[HTS_URLMAXSIZE*2];
+  char BIGSTK buff[HTS_URLMAXSIZE*2];
+  char BIGSTK location_default[HTS_URLMAXSIZE*2];
+  char BIGSTK previous_save[HTS_URLMAXSIZE*2];
   htsblk r;
   int ok=0;
   int header_only=0;
@@ -1073,7 +1073,7 @@ static htsblk cache_readex_old(httrackp* opt,cache_back* cache,char* adr,char* f
 /* 0 if failed */
 int cache_writedata(FILE* cache_ndx,FILE* cache_dat,char* str1,char* str2,char* outbuff,int len) {
   if (cache_dat) {
-    char buff[HTS_URLMAXSIZE*4];
+    char BIGSTK buff[HTS_URLMAXSIZE*4];
     char s[256];
     int pos;
     fflush(cache_dat); fflush(cache_ndx);
@@ -1100,7 +1100,7 @@ int cache_writedata(FILE* cache_ndx,FILE* cache_dat,char* str1,char* str2,char*
 int cache_readdata(cache_back* cache,char* str1,char* str2,char** inbuff,int* inlen) {
 #if HTS_FAST_CACHE
   if (cache->hashtable) {
-    char buff[HTS_URLMAXSIZE*4];
+    char BIGSTK buff[HTS_URLMAXSIZE*4];
     long int pos;
     strcpybuff(buff,str1); strcatbuff(buff,str2);
     if (inthash_read((inthash)cache->hashtable,buff,(long int*)&pos)) {
@@ -1256,7 +1256,7 @@ void cache_init(cache_back* cache,httrackp* opt) {
         /* Ready directory entries */
         if (unzGoToFirstFile((unzFile) cache->zipInput) == Z_OK) {
           char comment[128];
-          char filename[HTS_URLMAXSIZE * 4];
+          char BIGSTK filename[HTS_URLMAXSIZE * 4];
           int entries = 0;
           memset(comment, 0, sizeof(comment));       // for truncated reads
           do  {
@@ -1271,7 +1271,7 @@ void cache_init(cache_back* cache,httrackp* opt) {
                 ) 
               {
                 long int pos = (long int) unzGetOffset((unzFile) cache->zipInput);
-				assertf(readSizeHeader < sizeof(comment));
+                assertf(readSizeHeader < sizeof(comment));
                 comment[readSizeHeader] = '\0';
                 entries++;
                 if (pos > 0) {
@@ -1284,7 +1284,7 @@ void cache_init(cache_back* cache,httrackp* opt) {
                     int maxLine = 2;
                     char* a = comment;
                     while(*a && maxLine-- > 0) {      // parse only few first lines
-                      char line[1024];
+                      char BIGSTK line[1024];
                       line[0] = '\0';
                       a+=binput(a, line, sizeof(line) - 2);
                       if (strfield(line, "X-In-Cache:")) {
@@ -1415,7 +1415,7 @@ void cache_init(cache_back* cache,httrackp* opt) {
           /* Create hash table for the cache (MUCH FASTER!) */
 #if HTS_FAST_CACHE
           if (cache->use) {
-            char line[HTS_URLMAXSIZE*2];
+            char BIGSTK line[HTS_URLMAXSIZE*2];
             char linepos[256];
             int  pos;
             while ( (a!=NULL) && (a < (cache->use+buffl) ) ) {
