@@ -77,7 +77,7 @@ Please visit our Website: http://www.httrack.com
 #include "htsopt.h"
 
 // structure d'un lien
-typedef struct {
+typedef struct lien_url {
   char firstblock;      // flag 1=premier malloc 
   char link_import;     // lien import  la suite d'un moved - ne pas appliquer les rgles classiques up/down
   int depth;            // profondeur autorise lien ; >0 forte 0=faible
@@ -102,7 +102,7 @@ typedef struct {
 } lien_url;
 
 // chargement de fichiers en 'arrire plan'
-typedef struct {
+typedef struct lien_back {
 #if DEBUG_CHECKINT
   char magic;
 #endif
@@ -149,7 +149,7 @@ typedef struct {
 typedef struct cache_back_zip_entry cache_back_zip_entry;
 
 // cache
-typedef struct {
+typedef struct cache_back {
   int version;        // 0 ou 1
   /* */
   int type;
@@ -177,7 +177,7 @@ typedef struct {
   int zipEntriesCapa;
 } cache_back;
 
-typedef struct {
+typedef struct hash_struct {
   lien_url** liens;                     // pointeur sur liens
   int max_lien;                         // indice le plus grand rencontr
   int hash[3][HTS_HASH_SIZE];           // tables pour sav/adr-fil/former_adr-former_fil
@@ -188,7 +188,7 @@ typedef struct {
 #define hash_write(A,B)
 #endif
 
-typedef struct {
+typedef struct filecreate_params {
   FILE* lst;
   char path[HTS_URLMAXSIZE*2];
 } filecreate_params;
@@ -272,6 +272,7 @@ typedef void  (* t_hts_htmlcheck_uninit)(void);
 typedef int   (* t_hts_htmlcheck_start)(httrackp* opt);
 typedef int   (* t_hts_htmlcheck_end)(void);
 typedef int   (* t_hts_htmlcheck_chopt)(httrackp* opt);
+typedef int   (* t_hts_htmlcheck_process)(char** html,int* len,char* url_adresse,char* url_fichier);
 typedef int   (* t_hts_htmlcheck)(char* html,int len,char* url_adresse,char* url_fichier);
 typedef char* (* t_hts_htmlcheck_query)(char* question);
 typedef char* (* t_hts_htmlcheck_query2)(char* question);
@@ -281,6 +282,7 @@ typedef int   (* t_hts_htmlcheck_check)(char* adr,char* fil,int status);
 typedef void  (* t_hts_htmlcheck_pause)(char* lockfile);
 typedef void  (* t_hts_htmlcheck_filesave)(char* file);
 typedef int   (* t_hts_htmlcheck_linkdetected)(char* link);
+typedef int   (* t_hts_htmlcheck_linkdetected2)(char* link, char* tag_start);
 typedef int   (* t_hts_htmlcheck_xfrstatus)(lien_back* back);
 typedef int   (* t_hts_htmlcheck_savename)(char* adr_complete,char* fil_complete,char* referer_adr,char* referer_fil,char* save);
 typedef int   (* t_hts_htmlcheck_sendhead)(char* buff, char* adr, char* fil, char* referer_adr, char* referer_fil, htsblk* outgoing);
@@ -296,6 +298,8 @@ extern t_hts_htmlcheck_uninit     hts_htmlcheck_uninit;
 extern t_hts_htmlcheck_start      hts_htmlcheck_start;
 extern t_hts_htmlcheck_end        hts_htmlcheck_end;
 extern t_hts_htmlcheck_chopt      hts_htmlcheck_chopt;
+extern t_hts_htmlcheck_process    hts_htmlcheck_preprocess;
+extern t_hts_htmlcheck_process    hts_htmlcheck_postprocess;
 extern t_hts_htmlcheck            hts_htmlcheck;
 extern t_hts_htmlcheck_query      hts_htmlcheck_query;
 extern t_hts_htmlcheck_query2     hts_htmlcheck_query2;
@@ -305,6 +309,7 @@ extern t_hts_htmlcheck_check      hts_htmlcheck_check;
 extern t_hts_htmlcheck_pause      hts_htmlcheck_pause;
 extern t_hts_htmlcheck_filesave   hts_htmlcheck_filesave;
 extern t_hts_htmlcheck_linkdetected hts_htmlcheck_linkdetected;
+extern t_hts_htmlcheck_linkdetected2 hts_htmlcheck_linkdetected2;
 extern t_hts_htmlcheck_xfrstatus  hts_htmlcheck_xfrstatus;
 extern t_hts_htmlcheck_savename   hts_htmlcheck_savename;
 extern t_hts_htmlcheck_sendhead   hts_htmlcheck_sendhead;
@@ -376,6 +381,8 @@ int liens_record(char* adr,char* fil,char* save,char* former_adr,char* former_fi
 
 
 // backing, routines externes
+int back_pluggable_sockets(lien_back* back, int back_max, httrackp* opt);
+int back_pluggable_sockets_strict(lien_back* back, int back_max, httrackp* opt);
 int back_fill(lien_back* back,int back_max,httrackp* opt,cache_back* cache,lien_url** liens,int ptr,int numero_passe,int lien_tot);
 int backlinks_done(lien_url** liens,int lien_tot,int ptr);
 int back_fillmax(lien_back* back,int back_max,httrackp* opt,cache_back* cache,lien_url** liens,int ptr,int numero_passe,int lien_tot);
