@@ -104,7 +104,7 @@ extern int IPV6_resolver;
   } \
 } while(0)
 
-static void set_wrappers(void) {
+void set_wrappers(void) {
 #if HTS_ANALYSTE
   // custom wrappers
   hts_htmlcheck_init         = (t_hts_htmlcheck_init)           htswrap_read("init");
@@ -112,6 +112,8 @@ static void set_wrappers(void) {
   hts_htmlcheck_start        = (t_hts_htmlcheck_start)          htswrap_read("start");
   hts_htmlcheck_end          = (t_hts_htmlcheck_end)            htswrap_read("end");
   hts_htmlcheck_chopt        = (t_hts_htmlcheck_chopt)          htswrap_read("change-options");
+  hts_htmlcheck_preprocess   = (t_hts_htmlcheck_process)        htswrap_read("preprocess-html");
+  hts_htmlcheck_postprocess  = (t_hts_htmlcheck_process)        htswrap_read("postprocess-html");
   hts_htmlcheck              = (t_hts_htmlcheck)                htswrap_read("check-html");
   hts_htmlcheck_query        = (t_hts_htmlcheck_query)          htswrap_read("query");
   hts_htmlcheck_query2       = (t_hts_htmlcheck_query2)         htswrap_read("query2");
@@ -121,6 +123,7 @@ static void set_wrappers(void) {
   hts_htmlcheck_pause        = (t_hts_htmlcheck_pause)          htswrap_read("pause");
   hts_htmlcheck_filesave     = (t_hts_htmlcheck_filesave)       htswrap_read("save-file");
   hts_htmlcheck_linkdetected = (t_hts_htmlcheck_linkdetected)   htswrap_read("link-detected");
+  hts_htmlcheck_linkdetected2 = (t_hts_htmlcheck_linkdetected2) htswrap_read("link-detected2");
   hts_htmlcheck_xfrstatus    = (t_hts_htmlcheck_xfrstatus)      htswrap_read("transfer-status");
   hts_htmlcheck_savename     = (t_hts_htmlcheck_savename)       htswrap_read("save-name");
   hts_htmlcheck_sendhead     = (t_hts_htmlcheck_sendhead)       htswrap_read("send-header");
@@ -252,7 +255,7 @@ int main(int argc, char **argv) {
   //httrack.maxcache_anticipate=256;  // maximum de liens  anticiper
   httrack.maxtime=-1;        // temps max en secondes
   httrack.maxrate=-1;        // pas de taux maxi
-  httrack.maxconn=10;        // nombre connexions/s
+  httrack.maxconn=10.0;      // nombre connexions/s
   httrack.waittime=-1;       // wait until.. hh*3600+mm*60+ss
   //
   httrack.exec=argv[0];
@@ -345,6 +348,15 @@ int main(int argc, char **argv) {
   strcpybuff(httrack.path_bin, HTS_HTTRACKDIR);
 #endif
 
+  /* libhttrack-plugin DLL preload (libhttrack-plugin.so or libhttrack-plugin.dll) */
+  {
+    void* userfunction = getFunctionPtr(&httrack, "libhttrack-plugin", "plugin_init");
+    if (userfunction != NULL) {
+      t_hts_htmlcheck_init initFnc = (t_hts_htmlcheck_init) userfunction;
+      initFnc();
+      set_wrappers();		/* Re-read wrappers internal static functions */
+    }
+  }
 
   /* filter CR, LF, TAB.. */
   {
@@ -590,7 +602,7 @@ int main(int argc, char **argv) {
     if (fp) {
       int insert_after=1;     /* insrer aprs nom au dbut */
       //
-      char buff[8192];
+      char BIGSTK buff[8192];
       char *p,*lastp;
       linput(fp,buff,8000);
       fclose(fp); fp=NULL;
@@ -1161,13 +1173,13 @@ int main(int argc, char **argv) {
             {
               sscanf(com+1,"%d",&httrack.savename_83); 
               switch(httrack.savename_83) {
-              case 0:
+              case 0:    // 8-3 (ISO9660 L1)
                 httrack.savename_83=1;
                 break;
               case 1:
                 httrack.savename_83=0;
                 break;
-              default:
+              default:    // 2 == ISO9660 (ISO9660 L2)
                 httrack.savename_83=2;
                 break;
               }
@@ -1206,7 +1218,7 @@ int main(int argc, char **argv) {
             case 'q': httrack.includequery=1; if (*(com+1)=='0') { httrack.includequery=0; com++; } break;   // No passwords in html files
             case 'I': httrack.kindex=1; if (isdigit((unsigned char)*(com+1))) { sscanf(com+1,"%d",&httrack.kindex); while(isdigit((unsigned char)*(com+1))) com++; }
               break;    // Keyword Index
-            case 'c': sscanf(com+1,"%d",&httrack.maxconn); while(isdigit((unsigned char)*(com+1))) com++; break;
+            case 'c': sscanf(com+1,"%f",&httrack.maxconn); while(isdigit((unsigned char)*(com+1)) || *(com+1) == '.') com++; break;
             case 'e': sscanf(com+1,"%d",&httrack.extdepth); while(isdigit((unsigned char)*(com+1))) com++; break;
             case 'B': httrack.tolerant=1; if (*(com+1)=='0') { httrack.tolerant=0; com++; } break;   // HTTP/1.0 notamment
             case 'h': httrack.http10=1; if (*(com+1)=='0') { httrack.http10=0; com++; } break;   // HTTP/1.0
@@ -1420,9 +1432,9 @@ int main(int argc, char **argv) {
                         if (htswrap_add(callbackname, userfunction)) {
                           set_wrappers();		/* Re-read wrappers internal static functions */
                           if ((void*)htswrap_read(callbackname) == userfunction) {
-	                        if (!httrack.quiet) {
-						      fprintf(stderr, "successfully plugged [%s -> %s:%s]\n", callbackname, posf, filename);
-				            }
+                            if (!httrack.quiet) {
+                              fprintf(stderr, "successfully plugged [%s -> %s:%s]\n", callbackname, posf, filename);
+                            }
                           } else {
                             char BIGSTK tmp[1024 * 2];
                             sprintf(tmp, "option %%W : unable to (re)plug the function %s from the file %s for the callback %s", posf, filename, callbackname);
@@ -1811,6 +1823,19 @@ int main(int argc, char **argv) {
                 return 0;
               }
               break;
+            case '1':   /* test #1 : fil_simplifie */
+              if (na+1>=argc) {
+                HTS_PANIC_PRINTF("Option #1 needs to be followed by an URL");
+                printf("Example: '-#0' ./foo/bar/../foobar\n");
+                htsmain_free();
+                return -1;
+              } else {
+                fil_simplifie(argv[na+1]);
+                printf("simplified=%s\n", argv[na+1]);
+                htsmain_free();
+                return 0;
+              }
+              break;
             case '!':
               if (na+1>=argc) {
                 HTS_PANIC_PRINTF("Option #! needs to be followed by a commandline");
@@ -2246,6 +2271,7 @@ int main(int argc, char **argv) {
   }
 #if HTS_ANALYSTE
   hts_htmlcheck_init();
+  set_wrappers();   // init() is allowed to set other wrappers
 #endif
 
   // dtourner SIGHUP etc.
@@ -2314,31 +2340,31 @@ deprecated - see SIGCHLD
       }
     }
 
-  /* Info for wrappers */
-  if ( (httrack.debug>0) && (httrack.log!=NULL) ) {
-    fspc(httrack.log,"info"); fprintf(httrack.log,"engine: free"LF);
-  }
+    /* Info for wrappers */
+    if ( (httrack.debug>0) && (httrack.log!=NULL) ) {
+      fspc(httrack.log,"info"); fprintf(httrack.log,"engine: free"LF);
+    }
 #if HTS_ANALYSTE
-  hts_htmlcheck_uninit();
+    hts_htmlcheck_uninit();
 #endif
-    
+
     if (httrack_logmode!=1) {
       if (httrack.errlog == httrack.log) httrack.errlog=NULL;
       if (httrack.log) { fclose(httrack.log); httrack.log=NULL; }
       if (httrack.errlog) { fclose(httrack.errlog); httrack.errlog=NULL; }
     }  
-    
+
     // Dbuggage des en ttes
     if (_DEBUG_HEAD) {
       if (ioinfo) {
         fclose(ioinfo);
       }
     }
-    
+
     // supprimer lock
     remove(n_lock);
   }
-  
+
   if (x_argvblk)
     freet(x_argvblk);
   if (x_argv)
@@ -2406,7 +2432,7 @@ int check_path(char* s,char* defaultname) {
 // dtermine si l'argument est une option
 int cmdl_opt(char* s) {
   if (s[0]=='-') {  // c'est peut tre une option
-    if (strchr(s,'.')!=NULL)
+    if (strchr(s,'.')!=NULL && strchr(s,'%')==NULL)
       return 0;    // sans doute un -www.truc.fr (note: -www n'est pas compris)
     else if (strchr(s,'/')!=NULL)
       return 0;    // idem, -*cgi-bin/
