@@ -43,6 +43,7 @@ typedef void  (* t_hts_htmlcheck_uninit)(void);
 typedef int   (* t_hts_htmlcheck_start)(httrackp* opt);
 typedef int   (* t_hts_htmlcheck_end)(void);
 typedef int   (* t_hts_htmlcheck_chopt)(httrackp* opt);
+typedef int   (* t_hts_htmlcheck_process)(char** html,int* len,char* url_adresse,char* url_fichier);
 typedef int   (* t_hts_htmlcheck)(char* html,int len,char* url_adresse,char* url_fichier);
 typedef char* (* t_hts_htmlcheck_query)(char* question);
 typedef char* (* t_hts_htmlcheck_query2)(char* question);
@@ -52,6 +53,7 @@ typedef int   (* t_hts_htmlcheck_check)(char* adr,char* fil,int status);
 typedef void  (* t_hts_htmlcheck_pause)(char* lockfile);
 typedef void  (* t_hts_htmlcheck_filesave)(char* file);
 typedef int   (* t_hts_htmlcheck_linkdetected)(char* link);
+typedef int   (* t_hts_htmlcheck_linkdetected2)(char* link, char* tag_start);
 typedef int   (* t_hts_htmlcheck_xfrstatus)(lien_back* back);
 typedef int   (* t_hts_htmlcheck_savename)(char* adr_complete,char* fil_complete,char* referer_adr,char* referer_fil,char* save);
 typedef int   (* t_hts_htmlcheck_sendhead)(char* buff, char* adr, char* fil, char* referer_adr, char* referer_fil, htsblk* outgoing);
@@ -67,6 +69,8 @@ extern t_hts_htmlcheck_uninit     hts_htmlcheck_uninit;
 extern t_hts_htmlcheck_start      hts_htmlcheck_start;
 extern t_hts_htmlcheck_end        hts_htmlcheck_end;
 extern t_hts_htmlcheck_chopt      hts_htmlcheck_chopt;
+extern t_hts_htmlcheck_process    hts_htmlcheck_preprocess;
+extern t_hts_htmlcheck_process    hts_htmlcheck_postprocess;
 extern t_hts_htmlcheck            hts_htmlcheck;
 extern t_hts_htmlcheck_query      hts_htmlcheck_query;
 extern t_hts_htmlcheck_query2     hts_htmlcheck_query2;
@@ -76,6 +80,7 @@ extern t_hts_htmlcheck_check      hts_htmlcheck_check;
 extern t_hts_htmlcheck_pause      hts_htmlcheck_pause;
 extern t_hts_htmlcheck_filesave   hts_htmlcheck_filesave;
 extern t_hts_htmlcheck_linkdetected hts_htmlcheck_linkdetected;
+extern t_hts_htmlcheck_linkdetected2 hts_htmlcheck_linkdetected2;
 extern t_hts_htmlcheck_xfrstatus  hts_htmlcheck_xfrstatus;
 extern t_hts_htmlcheck_savename   hts_htmlcheck_savename;
 extern t_hts_htmlcheck_sendhead   hts_htmlcheck_sendhead;
