@@ -40,8 +40,8 @@ Please visit our Website: http://www.httrack.com
 #define HTTRACK_GLOBAL_DEFH
 
 // Version
-#define HTTRACK_VERSION      "3.32-3"
-#define HTTRACK_VERSIONID    "3.32.03"
+#define HTTRACK_VERSION      "3.33"
+#define HTTRACK_VERSIONID    "3.33.15"
 #define HTTRACK_AFF_VERSION  "3.x"
 //#define HTTRACK_AFF_WARNING  "This is a BETA release of WinHTTrack Website Copier ("HTTRACK_VERSION")\nPlease report any crashes, bugs or problems"
 
@@ -287,7 +287,7 @@ Please visit our Website: http://www.httrack.com
 #endif
 
 /* Copyright (C) Xavier Roche and other contributors */
-#define HTTRACK_AFF_AUTHORS "[XR&CO'2004]"
+#define HTTRACK_AFF_AUTHORS "[XR&CO'2005]"
 #define HTS_DEFAULT_FOOTER "<!-- Mirrored from %s%s by HTTrack Website Copier/"HTTRACK_AFF_VERSION" "HTTRACK_AFF_AUTHORS", %s -->"
 #define HTTRACK_WEB "http://www.httrack.com"
 #define HTS_UPDATE_WEBSITE "http://www.httrack.com/update.php3?Product=HTTrack&Version="HTTRACK_VERSIONID"&VersionStr="HTTRACK_VERSION"&Platform=%d&Language=%s"
@@ -466,11 +466,11 @@ typedef int INTsys;
 //#define HTS_TRACE_MALLOC
 #ifdef HTS_TRACE_MALLOC
 typedef unsigned long int t_htsboundary;
-typedef struct _mlink {
+typedef struct mlink {
   char* adr;
   int len;
   int id;
-  struct _mlink* next;
+  struct mlink* next;
 } mlink;
 static const t_htsboundary htsboundary = 0xDEADBEEF;
 #endif
