@@ -334,7 +334,7 @@ int help_query(char* list,int def) {
 
 // Capture d'URL
 void help_catchurl(char* dest_path) {
-  char adr_prox[HTS_URLMAXSIZE*2];
+  char BIGSTK adr_prox[HTS_URLMAXSIZE*2];
   int port_prox;
   T_SOC soc=catch_url_init_std(&port_prox,adr_prox);
   if (soc!=INVALID_SOCKET) {
@@ -347,7 +347,7 @@ void help_catchurl(char* dest_path) {
     printf("\tProxy's address: \t%s\n\tProxy's port: \t%d\n",adr_prox,port_prox);
     //
     if (catch_url(soc,url,method,data)) {
-      char dest[HTS_URLMAXSIZE*2];
+      char BIGSTK dest[HTS_URLMAXSIZE*2];
       int i=0;
       do {
         sprintf(dest,"%s%s%d",dest_path,"hts-post",i);
@@ -362,7 +362,7 @@ void help_catchurl(char* dest_path) {
       }
       // former URL!
       {
-        char finalurl[HTS_URLMAXSIZE*2];
+        char BIGSTK finalurl[HTS_URLMAXSIZE*2];
         escape_check_url(dest);
         sprintf(finalurl,"%s"POSTTOK"file:%s",url,dest);
         printf("\nThe URL is: \"%s\"\n",finalurl);
@@ -479,6 +479,7 @@ void help(char* app,int more) {
   infomsg(" %u  url hacks: various hacks to limit duplicate URLs (strip //, www.foo.com==foo.com..)");
   infomsg(" %A  assume that a type (cgi,asp..) is always linked with a mime type (-%A php3,cgi=text/html;dat,bin=application/x-zip)");
   infomsg("     shortcut: '--assume standard' is equivalent to -%A "HTS_ASSUME_STANDARD);
+  infomsg("     can also be used to force a specific file type: --assume foo.cgi=text/html");
   infomsg(" @iN internet protocol (0=both ipv6+ipv4, 4=ipv4 only, 6=ipv6 only)");
   infomsg("");
   infomsg("Browser ID:");
@@ -619,6 +620,8 @@ void help(char* app,int more) {
   infomsg("'start' : int   (* myfunction)(httrackp* opt);");
   infomsg("'end' : int   (* myfunction)(void);");
   infomsg("'change-options' : int   (* myfunction)(httrackp* opt);");
+  infomsg("'preprocess-html' : int   (* myfunction)(char** html,int* len,char* url_adresse,char* url_fichier);");
+  infomsg("'postprocess-html' : int   (* myfunction)(char** html,int* len,char* url_adresse,char* url_fichier);");
   infomsg("'check-html' : int   (* myfunction)(char* html,int len,char* url_adresse,char* url_fichier);");
   infomsg("'query' : char* (* myfunction)(char* question);");
   infomsg("'query2' : char* (* myfunction)(char* question);");
@@ -628,6 +631,7 @@ void help(char* app,int more) {
   infomsg("'pause' : void  (* myfunction)(char* lockfile);");
   infomsg("'save-file' : void  (* myfunction)(char* file);");
   infomsg("'link-detected' : int   (* myfunction)(char* link);");
+  infomsg("'link-detected2' : int   (* myfunction)(char* link, char* start_tag);");
   infomsg("'transfer-status' : int   (* myfunction)(lien_back* back);");
   infomsg("'save-name' : int   (* myfunction)(char* adr_complete,char* fil_complete,char* referer_adr,char* referer_fil,char* save);");
   infomsg("And <wrappername>_init() functions if defined, called upon plug");
