@@ -68,11 +68,12 @@ int inthash_write(inthash hashtable,char* name,long int value) {
     if (strcmp(h->name,name)==0) {
       /* Delete element */
       if (hashtable->flag_valueismalloc) {
-        if (h->value.intg) {
+        void* ptr = (void*)h->value.intg;
+        if (ptr != NULL) {
           if (hashtable->free_handler)
-            hashtable->free_handler((void*)h->value.intg);
+            hashtable->free_handler(ptr);
           else
-            freet((void*)h->value.intg);
+            freet(ptr);
         }
       }
       /* Insert */
@@ -181,12 +182,13 @@ void inthash_delchain(inthash_chain* hash,t_inthash_freehandler free_handler) {
     inthash_delchain(hash->next,free_handler);
     if (free_handler) {     // pos is a malloc() block, delete it!
       if (hash->value.intg) {
+        void* ptr = (void*)hash->value.intg;
         if (free_handler)
-          free_handler((void*)hash->value.intg);
+          free_handler(ptr);
         else
-          freet((void*)hash->value.intg);
+          freet(ptr);
+        hash->value.intg=0;
       }
-      hash->value.intg=0;
     }
     freet(hash);
   }
