@@ -56,8 +56,13 @@ Please visit our Website: http://www.httrack.com
 
 #include "htsopt.h"
 
+#define READ_ERROR (-1)
+#define READ_EOF (-2)
+#define READ_TIMEOUT (-3)
+#define READ_INTERNAL_ERROR (-4)
+
 // structure pour paramtres supplmentaires lors de la requte
-typedef struct {
+typedef struct htsrequest {
   short int user_agent_send;  // user agent (ex: httrack/1.0 [sun])
   short int http11;           // l'en tte peut (doit) tre sign HTTP/1.1 et non HTTP/1.0
   short int nokeepalive;      // pas de keep-alive
@@ -73,7 +78,7 @@ typedef struct {
 
 
 // structure pour retour d'une connexion/prise d'en tte
-typedef struct {
+typedef struct htsblk {
   int statuscode;        // status-code, -1=erreur, 200=OK,201=..etc (cf RFC1945)
   short int notmodified; // page ou fichier NON modifi (transfr)
   short int is_write;    // sortie sur disque (out) ou en mmoire (adr)
@@ -271,15 +276,16 @@ HTSEXT_API void escape_uri_utf(char* s);
 HTSEXT_API void escape_check_url(char* s);
 HTSEXT_API char* escape_check_url_addr(char* s);
 HTSEXT_API void x_escape_http(char* s,int mode);
+HTSEXT_API void x_escape_html(char* s);
 HTSEXT_API void escape_remove_control(char* s);
+HTSEXT_API void escape_for_html_print(char* s, char* d);
+HTSEXT_API void escape_for_html_print_full(char* s, char* d);
 #endif
-int ehexh(char c);
 #ifndef HTTRACK_DEFLIB
 HTSEXT_API char* unescape_http(char* s);
 HTSEXT_API char* unescape_http_unharm(char* s, int no_high);
 HTSEXT_API char* antislash_unescaped(char* s);
 #endif
-int ehex(char* s);
 char* concat(const char* a,const char* b);
 #define copychar(a) concat((a),NULL)
 #if HTS_DOSNAME
@@ -348,6 +354,8 @@ void  __cdecl htsdefault_uninit(void);
 int   __cdecl htsdefault_start(void* opt);
 int   __cdecl htsdefault_chopt(void* opt);
 int   __cdecl htsdefault_end(void);
+int   __cdecl htsdefault_preprocesshtml(char** html,int* len,char* url_adresse,char* url_fichier);
+int   __cdecl htsdefault_postprocesshtml(char** html,int* len,char* url_adresse,char* url_fichier);
 int   __cdecl htsdefault_checkhtml(char* html,int len,char* url_adresse,char* url_fichier);
 int   __cdecl htsdefault_loop(void* back,int back_max,int back_index,int lien_n,int lien_tot,int stat_time,hts_stat_struct* stats);
 char* __cdecl htsdefault_query(char* question);
@@ -357,6 +365,7 @@ int   __cdecl htsdefault_check(char* adr,char* fil,int status);
 void  __cdecl htsdefault_pause(char* lockfile);
 void  __cdecl htsdefault_filesave(char*);
 int   __cdecl htsdefault_linkdetected(char* link);
+int   __cdecl htsdefault_linkdetected2(char* link, char* tag_start);
 int   __cdecl htsdefault_xfrstatus(void* back);
 int   __cdecl htsdefault_savename(char* adr_complete,char* fil_complete,char* referer_adr,char* referer_fil,char* save);
 int   __cdecl htsdefault_sendheader(char* buff, char* adr, char* fil, char* referer_adr, char* referer_fil, htsblk* outgoing);
@@ -404,6 +413,11 @@ static int strcmpnocase(char* a,char* b) {
   return 0;
 }
 
+#ifdef _WIN32
+#define strcasecmp(a,b) stricmp(a,b)
+#define strncasecmp(a,b,n) strnicmp(a,b,n)
+#endif
+
 #define strfield2(f,s) ( (strlen(f)!=strlen(s)) ? 0 : (strfield(f,s)) )
 
 // is this MIME an hypertext MIME (text/html), html/js-style or other script/text type?
@@ -469,6 +483,32 @@ static int compare_mime(const char* mime, const char* file, const char* referenc
 
 #endif
 
+#ifdef _WIN32_WCE_XXC
+extern char cwd[MAX_PATH+1];
+static char *getcwd_ce(char *buffer, int maxlen)
+{
+	TCHAR fileUnc[MAX_PATH+1];
+	char* plast;
+	
+	if(cwd[0] == 0)
+	{
+		GetModuleFileName(NULL, fileUnc, MAX_PATH);
+		WideCharToMultiByte(CP_ACP, 0, fileUnc, -1, cwd, MAX_PATH, NULL, NULL);
+		plast = strrchr(cwd, '\\');
+		if(plast)
+			*plast = 0;
+		/* Special trick to keep start menu clean... */
+		if(_stricmp(cwd, "\\windows\\start menu") == 0)
+			strcpy(cwd, "\\Apps");
+	}
+	if(buffer)
+		strncpy(buffer, cwd, maxlen);
+	return cwd;
+}
+#undef getcwd
+#define getcwd getcwd_ce
+#endif
+
 #endif
 
 
