@@ -44,7 +44,7 @@ Please visit our Website: http://www.httrack.com
 #include "htsbauth.h"
 
 // structure proxy
-typedef struct {
+typedef struct t_proxy {
   int active;
   char name[1024];
   int port;
@@ -52,7 +52,7 @@ typedef struct {
 } t_proxy; 
 
 /* Structure utile pour copier en bloc les paramtres */
-typedef struct {
+typedef struct htsfilters {
   char***  filters;
   int*     filptr;
   //int*    filter_max;
@@ -69,7 +69,7 @@ struct htscallbacks {
 };
 
 /* Structure tat du miroir */
-typedef struct {
+typedef struct htsoptstate {
   int stop;
   int exit_xh;
   int back_add_stats;
@@ -83,7 +83,7 @@ typedef struct {
 
 
 // paramtres httrack (options)
-typedef struct {
+typedef struct httrackp {
   int wizard;       // wizard aucun/grand/petit
   int flush;        // fflush sur les fichiers log
   int travel;       // type de dplacements (same domain etc)
@@ -108,7 +108,7 @@ typedef struct {
   int rateout;          // nombre d'octets minium pour le transfert
   int maxtime;          // temps max en secondes
   int maxrate;          // taux de transfert max
-  int maxconn;          // nombre max de connexions/s
+  float maxconn;        // nombre max de connexions/s
   int waittime;         // dmarrage programm
   int cache;            // gnration d'un cache
   //int aff_progress;     // barre de progression
@@ -179,7 +179,7 @@ typedef struct {
 } httrackp;
 
 // stats for httrack
-typedef struct {
+typedef struct hts_stat_struct {
   LLint HTS_TOTAL_RECV;      // flux entrant reu
   LLint stat_bytes;          // octets crits sur disque
   // int HTS_TOTAL_RECV_STATE;  // status: 0 tout va bien 1: ralentir un peu 2: ralentir 3: beaucoup
@@ -208,6 +208,9 @@ typedef struct {
   LLint nb;                  // donnes transfres actuellement (estimation)
   //
   LLint rate;
+  //
+  TStamp last_connect;      // last connect() call
+  TStamp last_request;      // last request issued
 } hts_stat_struct;
 
 
