@@ -273,7 +273,7 @@ int smallserver(T_SOC soc,char* url,char* method,char* data, char* path) {
   {
     char pth[1024];
     char* initOn[] = { "parseall", "Cache", "ka", 
-      "cookies", "parsejava", "testall", "updhack", "index", NULL };
+      "cookies", "parsejava", "testall", "updhack", "urlhack", "index", NULL };
     initIntElt initInt[] = {
       { "filter", 4 },
       { "travel", 2 },
@@ -293,7 +293,7 @@ int smallserver(T_SOC soc,char* url,char* method,char* data, char* path) {
     };
     initStrElt initStr[] = {
       { "user", "Mozilla/4.5 (compatible; HTTrack 3.0x; Windows 98)" },
-      { "footer", "<!-- Mirrored from %s%s by HTTrack Website Copier/3.x [XR&CO'2004], %s -->" },
+      { "footer", "<!-- Mirrored from %s%s by HTTrack Website Copier/3.x [XR&CO'2005], %s -->" },
       { "url2", "+*.png +*.gif +*.jpg +*.css +*.js -ad.doubleclick.net/*" },
       { NULL, NULL }
     };
