@@ -92,10 +92,14 @@ int ident_url_relatif(char *lien,char* origin_adr,char* origin_fil,char* adr,cha
       ok=-2;  // non support
     }
 #if HTS_USEOPENSSL
-  } else if (SSL_is_available && strfield(lien,"https://")) {
-    // Note: ftp:foobar.gif is not valid
-    if (ident_url_absolute(lien,adr,fil)==-1) {        
-      ok=-1;    // erreur URL
+  } else if (strfield(lien,"https://")) {
+    if (SSL_is_available) {
+      // Note: ftp:foobar.gif is not valid
+      if (ident_url_absolute(lien,adr,fil)==-1) {        
+        ok=-1;    // erreur URL
+      }
+    } else {
+      ok=-1;
     }
 #endif
   } else if ((scheme) && (
@@ -192,8 +196,8 @@ int ident_url_relatif(char *lien,char* origin_adr,char* origin_fil,char* adr,cha
 // crer dans s,  partir du chemin courant curr_fil, le lien vers link (absolu)
 // un ident_url_relatif a dja t fait avant, pour que link ne soit pas un chemin relatif
 int lienrelatif(char* s,char* link,char* curr_fil) {
-  char _curr[HTS_URLMAXSIZE*2];
-  char newcurr_fil[HTS_URLMAXSIZE*2],newlink[HTS_URLMAXSIZE*2];
+  char BIGSTK _curr[HTS_URLMAXSIZE*2];
+  char BIGSTK newcurr_fil[HTS_URLMAXSIZE*2],newlink[HTS_URLMAXSIZE*2];
   char* curr;
   //int n=0;
   char* a;
@@ -327,7 +331,7 @@ void longfile_to_83(int mode,char* n83,char* save) {
     max=8;
     break;
   case 2:
-    max=30;
+    max=31;
     break;
   default:
     max=8;
@@ -350,21 +354,20 @@ void longfile_to_83(int mode,char* n83,char* save) {
     }
   }
   /* 
-    Avoid: (ISO9660, but also suitable for 8-3)
-    (Thanks to jonat@cellcast.com for te hint)
-    /:;?\#*~
-    0x00-0x1f and 0x80-0xff
+  Avoid: (ISO9660, but also suitable for 8-3)
+  (Thanks to jonat@cellcast.com for te hint)
+  /:;?\#*~
+  0x00-0x1f and 0x80-0xff
   */
-  for(i=0 ; i < (int) strlen(save) ; i++) {
-    if (
-      (strchr("/:;?\\#*~", save[i]))
-      ||
-      (save[i] < 32)
-      ||
-      (save[i] >= 127)
-      ) {
-      save[i]='_';
+  for(i = 0 ; save[i] != 0 ; i++) {
+    char a = save[i];
+    if (a >= 'a' && a <= 'z') {
+      a -= 'a' - 'A';
     }
+    else if ( ! ( (a >= 'A' && a <= 'Z') || (a >= '0' && a <= '9') || a == '_' || a == '.') ) {
+      a = '_';
+    }
+    save[i] = a;
   }
 
   i=j=0;
@@ -569,7 +572,7 @@ HTSEXT_API char* hts_getcategory(char* filename);
 HTSEXT_API int hts_buildtopindex(httrackp* opt,char* path,char* binpath) {
   FILE* fpo;
   int retval=0;
-  char rpath[1024*2];
+  char BIGSTK rpath[1024*2];
   char *toptemplate_header=NULL,*toptemplate_body=NULL,*toptemplate_footer=NULL,*toptemplate_bodycat=NULL;
   
   // et templates html
@@ -673,7 +676,7 @@ HTSEXT_API int hts_buildtopindex(httrackp* opt,char* path,char* binpath) {
             
             /* Build sorted index */
             for(i = 0 ; i < chainSize ; i++) {
-              char hname[HTS_URLMAXSIZE*2];
+              char BIGSTK hname[HTS_URLMAXSIZE*2];
               strcpybuff(hname,sortedElts[i]->name);
               escape_check_url(hname);
 
@@ -733,7 +736,7 @@ HTSEXT_API char* hts_getcategory(char* filename) {
     if (fp != NULL) {
       int done=0;
       while(!feof(fp) && !done) {
-        char line[1024];
+        char BIGSTK line[1024];
         int n = linput(fp, line, sizeof(line) - 2);
         if (n > 0) {
           if (strfield(line, "category=")) {
@@ -771,7 +774,7 @@ HTSEXT_API char* hts_getcategories(char* path, int type) {
     }
     do {
       if (hts_findisdir(h)) {
-        char line2[1024];
+        char BIGSTK line2[1024];
         StringStrcpy(iname,rpath);
         StringStrcat(iname,"/");
         StringStrcat(iname,hts_findgetname(h));
@@ -849,7 +852,7 @@ HTSEXT_API find_handle hts_findfirst(char* path) {
         memset(find, 0, sizeof(find_handle_struct));
 #if HTS_WIN
         {
-          char rpath[1024*2];
+          char BIGSTK rpath[1024*2];
           strcpybuff(rpath,path);
           if (rpath[0]) {
             if (rpath[strlen(rpath)-1]!='\\')
