@@ -56,12 +56,12 @@ Please visit our Website: http://www.httrack.com
 
 // Portable directory find functions
 #ifdef _WIN32
-typedef struct {
+typedef struct find_handle_struct {
   WIN32_FIND_DATAA hdata;
   HANDLE handle;
 } find_handle_struct;
 #else
-typedef struct {
+typedef struct find_handle_struct {
   DIR * hdir;
   struct dirent* dirp;
   struct stat filestat;
