@@ -167,8 +167,8 @@ int hts_acceptlink(httrackp* opt,
     {  // tester interdiction de descendre
       // MODIFIE : en cas de remonte puis de redescente, il se pouvait qu'on ne puisse pas atteindre certains fichiers
       // problme: si un fichier est virtuellement accessible via une page mais dont le lien est sur une autre *uniquement*..
-      char tempo[HTS_URLMAXSIZE*2];
-      char tempo2[HTS_URLMAXSIZE*2];
+      char BIGSTK tempo[HTS_URLMAXSIZE*2];
+      char BIGSTK tempo2[HTS_URLMAXSIZE*2];
       tempo[0] = tempo2[0] = '\0';
       
       // note (up/down): on calcule  partir du lien primaire, ET du lien prcdent.
@@ -292,8 +292,8 @@ int hts_acceptlink(httrackp* opt,
     }  // tester interdiction de descendre?
     
     {  // tester interdiction de monter
-      char tempo[HTS_URLMAXSIZE*2];
-      char tempo2[HTS_URLMAXSIZE*2];
+      char BIGSTK tempo[HTS_URLMAXSIZE*2];
+      char BIGSTK tempo2[HTS_URLMAXSIZE*2];
       if (lienrelatif(tempo,fil,liens[liens[ptr]->premier]->fil)==0) {
         if (lienrelatif(tempo2,fil,liens[ptr]->fil)==0) {
         } else {
@@ -417,8 +417,8 @@ int hts_acceptlink(httrackp* opt,
     int question=1;         // poser une question                            
     int force_mirror=0;     // pour mirror links
     int filters_answer=0;   // dcision prise par les filtres
-    char l[HTS_URLMAXSIZE*2];
-    char lfull[HTS_URLMAXSIZE*2];
+    char BIGSTK l[HTS_URLMAXSIZE*2];
+    char BIGSTK lfull[HTS_URLMAXSIZE*2];
     
     if (forbidden_url!=-1) question=0;  // pas de question, rsolu
     
@@ -621,7 +621,7 @@ int hts_acceptlink(httrackp* opt,
         HTS_REQUEST_END;
 #if HTS_ANALYSTE
           {
-            char tempo[HTS_URLMAXSIZE*2];
+            char BIGSTK tempo[HTS_URLMAXSIZE*2];
             tempo[0]='\0';
             strcatbuff(tempo,adr);
             strcatbuff(tempo,"/");
@@ -854,8 +854,8 @@ int hts_testlinksize(httrackp* opt,
                      LLint size) {
   int jok=0;
   if (size>=0) {
-    char l[HTS_URLMAXSIZE*2];
-    char lfull[HTS_URLMAXSIZE*2];
+    char BIGSTK l[HTS_URLMAXSIZE*2];
+    char BIGSTK lfull[HTS_URLMAXSIZE*2];
     if (size>=0) {
       LLint sz=size;
       int size_flag=0;
