@@ -73,9 +73,6 @@ static int linput(FILE* fp,char* s,int max);
 #include <unistd.h>
 #endif
 #include <ctype.h>
-#ifdef _WIN32
-//#include "Winsock.h"
-#endif
 /* END specific definitions */
 
 // ISO VT100/220 definitions
@@ -155,7 +152,13 @@ Log: "engine: end"
   hts_htmlcheck_chopt        = (t_hts_htmlcheck_chopt)          htswrap_read("change-options");
 Log: "engine: change-options"
 
-  hts_htmlcheck              = (t_hts_htmlcheck)                htswrap_read("check-html");
+  hts_htmlcheck_preprocess   = (t_hts_htmlcheck_process)        htswrap_read("preprocess-html");
+Log: "preprocess-html: <url>"
+
+  hts_htmlcheck_postprocess   = (t_hts_htmlcheck_process)        htswrap_read("postprocess-html");
+Log: "postprocess-html: <url>"
+
+hts_htmlcheck              = (t_hts_htmlcheck)                htswrap_read("check-html");
 Log: "check-html: <url>"
 
   hts_htmlcheck_query        = (t_hts_htmlcheck_query)          htswrap_read("query");
@@ -170,6 +173,7 @@ Log: "pause: <lockfile>"
 
   hts_htmlcheck_filesave     = (t_hts_htmlcheck_filesave)       htswrap_read("save-file");
   hts_htmlcheck_linkdetected = (t_hts_htmlcheck_linkdetected)   htswrap_read("link-detected");
+  hts_htmlcheck_linkdetected2 = (t_hts_htmlcheck_linkdetected2)   htswrap_read("link-detected2");
 Log: none
 
   hts_htmlcheck_xfrstatus    = (t_hts_htmlcheck_xfrstatus)      htswrap_read("transfer-status");
@@ -188,6 +192,8 @@ Log:
   htswrap_add("start",htsshow_start);
   htswrap_add("change-options",htsshow_chopt);
   htswrap_add("end",htsshow_end);
+  htswrap_add("preprocess-html",htsshow_preprocesshtml);
+  htswrap_add("postprocess-html",htsshow_preprocesshtml);
   htswrap_add("check-html",htsshow_checkhtml);
   htswrap_add("loop",htsshow_loop);
   htswrap_add("query",htsshow_query);
@@ -197,6 +203,7 @@ Log:
   htswrap_add("pause",htsshow_pause);
   htswrap_add("save-file",htsshow_filesave);
   htswrap_add("link-detected",htsshow_linkdetected);
+  htswrap_add("link-detected2",htsshow_linkdetected2);
   htswrap_add("transfer-status",htsshow_xfrstatus);
   htswrap_add("save-name",htsshow_savename);
   htswrap_add("send-header", htsshow_sendheader);
@@ -252,6 +259,9 @@ static int __cdecl htsshow_chopt(httrackp* opt) {
 static int  __cdecl htsshow_end(void) { 
   return 1; 
 }
+static int __cdecl htsshow_preprocesshtml(char** html,int* len,char* url_adresse,char* url_fichier) {
+  return 1;
+}
 static int __cdecl htsshow_checkhtml(char* html,int len,char* url_adresse,char* url_fichier) {
   return 1;
 }
@@ -447,7 +457,7 @@ static int __cdecl htsshow_loop(lien_back* back,int back_max,int back_index,int
               }
               
               if (ok) {
-                char s[HTS_URLMAXSIZE*2];
+                char BIGSTK s[HTS_URLMAXSIZE*2];
                 //
                 StatsBuffer[index].back=i;        // index pour + d'infos
                 //
@@ -519,6 +529,15 @@ static int __cdecl htsshow_loop(lien_back* back,int back_max,int back_index,int
           case 2:
             printf("purging files");
             break;
+          case 3:
+            printf("loading cache");
+            break;
+          case 4:
+            printf("waiting (scheduler)");
+            break;
+          case 5:
+            printf("waiting (throttle)");
+            break;
           }
         }
         printf("%s\n",VT_CLREOL);
@@ -583,6 +602,9 @@ static void __cdecl htsshow_filesave(char* file) {
 static int __cdecl htsshow_linkdetected(char* link) {
   return 1;
 }
+static int __cdecl htsshow_linkdetected2(char* link, char* start_tag) {
+  return 1;
+}
 static int __cdecl htsshow_xfrstatus(lien_back* back) {
   return 1;
 }
