@@ -46,9 +46,9 @@ typedef struct {
   char name[1024];
   char file[1024];
   char state[256];
-  char url_sav[HTS_URLMAXSIZE*2];    // pour cancel
-  char url_adr[HTS_URLMAXSIZE*2];
-  char url_fil[HTS_URLMAXSIZE*2];
+  char BIGSTK url_sav[HTS_URLMAXSIZE*2];    // pour cancel
+  char BIGSTK url_adr[HTS_URLMAXSIZE*2];
+  char BIGSTK url_fil[HTS_URLMAXSIZE*2];
   LLint size;
   LLint sizetot;
   int offset;
@@ -84,6 +84,8 @@ static void  __cdecl htsshow_uninit(void);
 static int   __cdecl htsshow_start(httrackp* opt);
 static int   __cdecl htsshow_chopt(httrackp* opt);
 static int   __cdecl htsshow_end(void);
+static int   __cdecl htsshow_preprocesshtml(char** html,int* len,char* url_adresse,char* url_fichier);
+static int   __cdecl htsshow_postprocesshtml(char** html,int* len,char* url_adresse,char* url_fichier);
 static int   __cdecl htsshow_checkhtml(char* html,int len,char* url_adresse,char* url_fichier);
 static int   __cdecl htsshow_loop(lien_back* back,int back_max,int back_index,int lien_n,int lien_tot,int stat_time,hts_stat_struct* stats);
 static char* __cdecl htsshow_query(char* question);
@@ -93,6 +95,7 @@ static int   __cdecl htsshow_check(char* adr,char* fil,int status);
 static void  __cdecl htsshow_pause(char* lockfile);
 static void  __cdecl htsshow_filesave(char* file);
 static int   __cdecl htsshow_linkdetected(char* link);
+static int   __cdecl htsshow_linkdetected2(char* link, char* start_tag);
 static int   __cdecl htsshow_xfrstatus(lien_back* back);
 static int   __cdecl htsshow_savename(char* adr_complete,char* fil_complete,char* referer_adr,char* referer_fil,char* save);
 static int   __cdecl htsshow_sendheader(char* buff, char* adr, char* fil, char* referer_adr, char* referer_fil, htsblk* outgoing);
